@@ -1,6 +1,11 @@
 """Support for monitoring a Smappee energy sensor."""
 from homeassistant.components.sensor import SensorEntity
-from homeassistant.const import DEVICE_CLASS_POWER, ENERGY_WATT_HOUR, POWER_WATT, VOLT
+from homeassistant.const import (
+    DEVICE_CLASS_POWER,
+    ELECTRIC_POTENTIAL_VOLT,
+    ENERGY_WATT_HOUR,
+    POWER_WATT,
+)
 
 from .const import DOMAIN
 
@@ -93,7 +98,7 @@ VOLTAGE_SENSORS = {
     "phase_voltages_a": [
         "Phase voltages - A",
         "mdi:flash",
-        VOLT,
+        ELECTRIC_POTENTIAL_VOLT,
         "phase_voltage_a",
         None,
         ["ONE", "TWO", "THREE_STAR", "THREE_DELTA"],
@@ -101,7 +106,7 @@ VOLTAGE_SENSORS = {
     "phase_voltages_b": [
         "Phase voltages - B",
         "mdi:flash",
-        VOLT,
+        ELECTRIC_POTENTIAL_VOLT,
         "phase_voltage_b",
         None,
         ["TWO", "THREE_STAR", "THREE_DELTA"],
@@ -109,7 +114,7 @@ VOLTAGE_SENSORS = {
     "phase_voltages_c": [
         "Phase voltages - C",
         "mdi:flash",
-        VOLT,
+        ELECTRIC_POTENTIAL_VOLT,
         "phase_voltage_c",
         None,
         ["THREE_STAR"],
@@ -117,7 +122,7 @@ VOLTAGE_SENSORS = {
     "line_voltages_a": [
         "Line voltages - A",
         "mdi:flash",
-        VOLT,
+        ELECTRIC_POTENTIAL_VOLT,
         "line_voltage_a",
         None,
         ["ONE", "TWO", "THREE_STAR", "THREE_DELTA"],
@@ -125,7 +130,7 @@ VOLTAGE_SENSORS = {
     "line_voltages_b": [
         "Line voltages - B",
         "mdi:flash",
-        VOLT,
+        ELECTRIC_POTENTIAL_VOLT,
         "line_voltage_b",
         None,
         ["TWO", "THREE_STAR", "THREE_DELTA"],
@@ -133,7 +138,7 @@ VOLTAGE_SENSORS = {
     "line_voltages_c": [
         "Line voltages - C",
         "mdi:flash",
-        VOLT,
+        ELECTRIC_POTENTIAL_VOLT,
         "line_voltage_c",
         None,
         ["THREE_STAR", "THREE_DELTA"],
@@ -149,38 +154,38 @@ async def async_setup_entry(hass, config_entry, async_add_entities):
     for service_location in smappee_base.smappee.service_locations.values():
         # Add all basic sensors (realtime values and aggregators)
         # Some are available in local only env
-        for sensor in TREND_SENSORS:
-            if not service_location.local_polling or TREND_SENSORS[sensor][5]:
+        for sensor, attributes in TREND_SENSORS.items():
+            if not service_location.local_polling or attributes[5]:
                 entities.append(
                     SmappeeSensor(
                         smappee_base=smappee_base,
                         service_location=service_location,
                         sensor=sensor,
-                        attributes=TREND_SENSORS[sensor],
+                        attributes=attributes,
                     )
                 )
 
         if service_location.has_reactive_value:
-            for reactive_sensor in REACTIVE_SENSORS:
+            for reactive_sensor, attributes in REACTIVE_SENSORS.items():
                 entities.append(
                     SmappeeSensor(
                         smappee_base=smappee_base,
                         service_location=service_location,
                         sensor=reactive_sensor,
-                        attributes=REACTIVE_SENSORS[reactive_sensor],
+                        attributes=attributes,
                     )
                 )
 
         # Add solar sensors (some are available in local only env)
         if service_location.has_solar_production:
-            for sensor in SOLAR_SENSORS:
-                if not service_location.local_polling or SOLAR_SENSORS[sensor][5]:
+            for sensor, attributes in SOLAR_SENSORS.items():
+                if not service_location.local_polling or attributes[5]:
                     entities.append(
                         SmappeeSensor(
                             smappee_base=smappee_base,
                             service_location=service_location,
                             sensor=sensor,
-                            attributes=SOLAR_SENSORS[sensor],
+                            attributes=attributes,
                         )
                     )
 
