@@ -1,9 +1,10 @@
 """Generic Z-Wave Entity Class."""
+from __future__ import annotations
 
 import logging
-from typing import List, Optional, Union
 
 from zwave_js_server.client import Client as ZwaveClient
+from zwave_js_server.const import NodeStatus
 from zwave_js_server.model.value import Value as ZwaveValue, get_value_id
 
 from homeassistant.config_entries import ConfigEntry
@@ -18,6 +19,8 @@ from .helpers import get_device_id, get_unique_id
 LOGGER = logging.getLogger(__name__)
 
 EVENT_VALUE_UPDATED = "value updated"
+EVENT_DEAD = "dead"
+EVENT_ALIVE = "alive"
 
 
 class ZWaveBaseEntity(Entity):
@@ -30,13 +33,28 @@ class ZWaveBaseEntity(Entity):
         self.config_entry = config_entry
         self.client = client
         self.info = info
-        self._name = self.generate_name()
-        self._unique_id = get_unique_id(
-            self.client.driver.controller.home_id, self.info.primary_value.value_id
-        )
         # entities requiring additional values, can add extra ids to this list
         self.watched_value_ids = {self.info.primary_value.value_id}
 
+        if self.info.additional_value_ids_to_watch:
+            self.watched_value_ids = self.watched_value_ids.union(
+                self.info.additional_value_ids_to_watch
+            )
+
+        # Entity class attributes
+        self._attr_name = self.generate_name()
+        self._attr_unique_id = get_unique_id(
+            self.client.driver.controller.home_id, self.info.primary_value.value_id
+        )
+        self._attr_entity_registry_enabled_default = (
+            self.info.entity_registry_enabled_default
+        )
+        self._attr_assumed_state = self.info.assumed_state
+        # device is precreated in main handler
+        self._attr_device_info = {
+            "identifiers": {get_device_id(self.client, self.info.node)},
+        }
+
     @callback
     def on_value_update(self) -> None:
         """Call when one of the watched values change.
@@ -46,7 +64,6 @@ class ZWaveBaseEntity(Entity):
 
     async def async_poll_value(self, refresh_all_values: bool) -> None:
         """Poll a value."""
-        assert self.hass
         if not refresh_all_values:
             self.hass.async_create_task(
                 self.info.node.async_poll_value(self.info.primary_value)
@@ -75,11 +92,15 @@ class ZWaveBaseEntity(Entity):
 
     async def async_added_to_hass(self) -> None:
         """Call when entity is added."""
-        assert self.hass  # typing
         # Add value_changed callbacks.
         self.async_on_remove(
             self.info.node.on(EVENT_VALUE_UPDATED, self._value_changed)
         )
+        for status_event in (EVENT_ALIVE, EVENT_DEAD):
+            self.async_on_remove(
+                self.info.node.on(status_event, self._node_status_alive_or_dead)
+            )
+
         self.async_on_remove(
             async_dispatcher_connect(
                 self.hass,
@@ -88,24 +109,23 @@ class ZWaveBaseEntity(Entity):
             )
         )
 
-    @property
-    def device_info(self) -> dict:
-        """Return device information for the device registry."""
-        # device is precreated in main handler
-        return {
-            "identifiers": {get_device_id(self.client, self.info.node)},
-        }
-
     def generate_name(
         self,
         include_value_name: bool = False,
-        alternate_value_name: Optional[str] = None,
-        additional_info: Optional[List[str]] = None,
+        alternate_value_name: str | None = None,
+        additional_info: list[str] | None = None,
+        name_suffix: str | None = None,
     ) -> str:
         """Generate entity name."""
         if additional_info is None:
             additional_info = []
-        name: str = self.info.node.name or self.info.node.device_config.description
+        name: str = (
+            self.info.node.name
+            or self.info.node.device_config.description
+            or f"Node {self.info.node.node_id}"
+        )
+        if name_suffix:
+            name = f"{name} {name_suffix}"
         if include_value_name:
             value_name = (
                 alternate_value_name
@@ -123,20 +143,23 @@ class ZWaveBaseEntity(Entity):
 
         return name
 
-    @property
-    def name(self) -> str:
-        """Return default name from device name and value name combination."""
-        return self._name
-
-    @property
-    def unique_id(self) -> str:
-        """Return the unique_id of the entity."""
-        return self._unique_id
-
     @property
     def available(self) -> bool:
         """Return entity availability."""
-        return self.client.connected and bool(self.info.node.ready)
+        return (
+            self.client.connected
+            and bool(self.info.node.ready)
+            and self.info.node.status != NodeStatus.DEAD
+        )
+
+    @callback
+    def _node_status_alive_or_dead(self, event_data: dict) -> None:
+        """
+        Call when node status changes to alive or dead.
+
+        Should not be overridden by subclasses.
+        """
+        self.async_write_ha_state()
 
     @callback
     def _value_changed(self, event_data: dict) -> None:
@@ -165,13 +188,13 @@ class ZWaveBaseEntity(Entity):
     @callback
     def get_zwave_value(
         self,
-        value_property: Union[str, int],
-        command_class: Optional[int] = None,
-        endpoint: Optional[int] = None,
-        value_property_key: Optional[int] = None,
+        value_property: str | int,
+        command_class: int | None = None,
+        endpoint: int | None = None,
+        value_property_key: int | None = None,
         add_to_watched_value_ids: bool = True,
         check_all_endpoints: bool = False,
-    ) -> Optional[ZwaveValue]:
+    ) -> ZwaveValue | None:
         """Return specific ZwaveValue on this ZwaveNode."""
         # use commandclass and endpoint from primary value if omitted
         return_value = None
@@ -193,13 +216,13 @@ class ZWaveBaseEntity(Entity):
         # If we haven't found a value and check_all_endpoints is True, we should
         # return the first value we can find on any other endpoint
         if return_value is None and check_all_endpoints:
-            for endpoint_ in self.info.node.endpoints:
-                if endpoint_.index != self.info.primary_value.endpoint:
+            for endpoint_idx in self.info.node.endpoints:
+                if endpoint_idx != self.info.primary_value.endpoint:
                     value_id = get_value_id(
                         self.info.node,
                         command_class,
                         value_property,
-                        endpoint=endpoint_.index,
+                        endpoint=endpoint_idx,
                         property_key=value_property_key,
                     )
                     return_value = self.info.node.values.get(value_id)
